==> apache-daffodil-3.1.0-src.zip: apache-daffodil-3.1.0-src/daffodil-test/src/test/scala/org/apache/daffodil/section05/facets/TestPatternRanges.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.daffodil.section05.facets

import org.apache.daffodil.tdml.Runner
import org.junit.AfterClass
import org.junit.Test

object TestPatternRanges {
  lazy val runner = Runner("/org/apache/daffodil/section05/facets", "PatternRanges.tdml")

  @AfterClass def shutDown = {
    runner.reset
  }
}

class TestPatternRanges {
  import org.apache.daffodil.section05.facets.TestPatternRanges._

  @Test def test_patternRanges1() = { runner.runOneTest("patternRanges1") }
  @Test def test_patternRanges2() = { runner.runOneTest("patternRanges2") }
  @Test def test_patternRangesXerces1() = { runner.runOneTest("patternRangesXerces1") }
  @Test def test_patternRangesXerces2() = { runner.runOneTest("patternRangesXerces2") }

}

==> apache-daffodil-3.2.0-src.zip: apache-daffodil-3.2.0-src/daffodil-test/src/test/scala/org/apache/daffodil/section05/facets/TestPatternRanges.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.daffodil.section05.facets

import org.apache.daffodil.tdml.Runner
import org.junit.AfterClass
import org.junit.Test

object TestPatternRanges {
  val runner = Runner("/org/apache/daffodil/section05/facets", "PatternRanges.tdml")

  @AfterClass def shutDown = {
    runner.reset
  }
}

class TestPatternRanges {
  import org.apache.daffodil.section05.facets.TestPatternRanges._

  @Test def test_patternRanges1() = { runner.runOneTest("patternRanges1") }
  @Test def test_patternRanges2() = { runner.runOneTest("patternRanges2") }
  @Test def test_patternRangesXerces1() = { runner.runOneTest("patternRangesXerces1") }
  @Test def test_patternRangesXerces2() = { runner.runOneTest("patternRangesXerces2") }

}
